// -*-c++-*-

/*
 *Copyright:

 Copyright (C) Hiroki SHIMORA

 This code is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 3, or (at your option)
 any later version.

 This code is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this code; see the file COPYING.  If not, write to
 the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.

 *EndCopyright:
 */

/////////////////////////////////////////////////////////////////////

#ifndef RCSC_COMMON_PERIODIC_CALLBACK_H
#define RCSC_COMMON_PERIODIC_CALLBACK_H

#include <boost/shared_ptr.hpp>

#include <vector>
#include <functional>

namespace rcsc {

/*!
  \class PeriodicCallback
  \brief abstract callback which are called every cycle periodically
*/
class PeriodicCallback
    : public std::unary_function< void, bool > {
public:

    //! smart pointer type
    typedef boost::shared_ptr< PeriodicCallback > Ptr;

    //! container type
    typedef std::vector< PeriodicCallback::Ptr > Cont;

    /*!
      \brief virtual destructor
    */
    virtual
    ~PeriodicCallback()
      { }

    /*!
      \brief this method will be called every cycle until this method returns true.
      \return true if no more call is needed.
    */
    virtual
    bool operator()() const = 0;
};

}

#endif
